@@ -1,8 +1,9 @@
 //===- llvm/Support/DiagnosticPrinter.h - Diagnostic Printer ----*- C++ -*-===//
 //
-// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
-// See https://llvm.org/LICENSE.txt for license information.
-// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+//                     The LLVM Compiler Infrastructure
+//
+// This file is distributed under the University of Illinois Open Source
+// License. See LICENSE.TXT for details.
 //
 //===----------------------------------------------------------------------===//
 //
@@ -18,7 +19,6 @@
 #include <string>
 
 namespace llvm {
-
 // Forward declarations.
 class Module;
 class raw_ostream;
@@ -27,10 +27,10 @@ class StringRef;
 class Twine;
 class Value;
 
-/// Interface for custom diagnostic printing.
+/// \brief Interface for custom diagnostic printing.
 class DiagnosticPrinter {
 public:
-  virtual ~DiagnosticPrinter() = default;
+  virtual ~DiagnosticPrinter() {}
 
   // Simple types.
   virtual DiagnosticPrinter &operator<<(char C) = 0;
@@ -57,7 +57,7 @@ public:
   virtual DiagnosticPrinter &operator<<(const SMDiagnostic &Diag) = 0;
 };
 
-/// Basic diagnostic printer that uses an underlying raw_ostream.
+/// \brief Basic diagnostic printer that uses an underlying raw_ostream.
 class DiagnosticPrinterRawOStream : public DiagnosticPrinter {
 protected:
   raw_ostream &Stream;
@@ -89,7 +89,6 @@ public:
   // Other types.
   DiagnosticPrinter &operator<<(const SMDiagnostic &Diag) override;
 };
+} // End namespace llvm
 
-} // end namespace llvm
-
-#endif // LLVM_IR_DIAGNOSTICPRINTER_H
+#endif
